.. currentmodule:: nengolib.synapses

nengolib\.synapses\.PadeDelay
=============================

.. autofunction:: nengolib.synapses.PadeDelay

nengolib\.synapses\.pade\_delay\_error
======================================

.. autofunction:: nengolib.synapses.pade_delay_error
